@@ -41,7 +41,7 @@ def main():
     utils.print_shadowsocks()
 
     if config['port_password']:
-        if config['server_port'] or config['password']:
+        if config['password']:
             logging.warn('warning: port_password should not be used with '
                          'server_port and password. server_port and password '
                          'will be ignored')
@@ -71,7 +71,8 @@ def main():
         def child_handler(signum, _):
             logging.warn('received SIGQUIT, doing graceful shutting down..')
             map(lambda s: s.close(next_tick=True), tcp_servers + udp_servers)
-        signal.signal(signal.SIGQUIT, child_handler)
+        signal.signal(getattr(signal, 'SIGQUIT', signal.SIGTERM),
+                      child_handler)
         try:
             loop = eventloop.EventLoop()
             dns_resolver.add_to_loop(loop)
