@@ -75,7 +75,7 @@ import random
 import encrypt
 import eventloop
 import lru_cache
-from common import parse_header
+from common import parse_header, pack_addr
 
 
 BUF_SIZE = 65536
@@ -214,8 +214,7 @@ class UDPRelay(object):
             if addrlen > 255:
                 # drop
                 return
-            data = '\x03' + chr(addrlen) + r_addr[0] + \
-                   struct.pack('>H', r_addr[1]) + data
+            data = pack_addr(r_addr[0]) + struct.pack('>H', r_addr[1]) + data
             response = encrypt.encrypt_all(self._password, self._method, 1,
                                            data)
             if not response:
@@ -261,12 +260,17 @@ class UDPRelay(object):
                     logging.error('UDP client_socket err')
                 self._handle_client(sock)
         now = time.time()
-        if now - self._last_time > 3.5:
+        if now - self._last_time > 3:
             self._cache.sweep()
-        if now - self._last_time > 7:
             self._client_fd_to_server_addr.sweep()
             self._last_time = now
+        if self._closed:
+            self._server_socket.close()
+            for sock in self._sockets:
+                sock.close()
+            self._eventloop.remove_handler(self._handle_events)
 
-    def close(self):
+    def close(self, next_tick=False):
         self._closed = True
-        self._server_socket.close()
+        if not next_tick:
+            self._server_socket.close()
